@@ -10,11 +10,10 @@ use Net::Prober;
 use Net::Prober::Probe::HTTP;
 
 my $result = Net::Prober::probe_http({
-    host    => '185.26.182.72',
-    timeout => 6.0,
-    port    => 80,
-    url     => '/pub/opera/',
-    match   => 'Index of /',
+    host    => 'operasoftware.pc.cdn.bitgravity.com',
+    timeout => 10.0,
+    url     => '/pub/opera/ping/ping.txt',
+    match   => '1',
 });
 
 say Dumper($result);
